@@ -27,7 +27,7 @@ class FieldsView:
         return f"FieldsView({', '.join(sorted(self._items))})"
 
     def __iter__(self) -> Iterator[str]:
-        return iter(self._items)
+        return iter(sorted(self._items, key=lambda field: ("." in field, field)))
 
     __repr__ = __str__
 
